@@ -15,11 +15,11 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 .IAPWS_STATES <- c(undef  = -1L,
-		  solid  = 0L,
-		  liquid = 1L,
-		  gas    = 2L,
-		  supercritical = 3L,
-		  saturated = 4L)
+		   solid  = 0L,
+		   liquid = 1L,
+		   gas    = 2L,
+		   supercritical = 3L,
+		   saturated = 4L)
 
 .check_state <- function(state)
 {
@@ -33,15 +33,15 @@
 }
 
 .IAPWS_PROPERTIES <- c(f  =  0L, g  =  1L,
-		 u  =  2L, h  =  3L,
-		 s  =  4L, t  =  5L,
-		 p  =  6L, v  =  7L,
-		 cp =  8L, cv =  9L,
-		 w  = 10L, rho = 11L,
-		 alpha = 12L, beta = 13L,
-		 chit = 14L,
-		 eta = 15L, lambda = 16L,
-		 sigma = 17L, epsilon = 18L)
+		       u  =  2L, h  =  3L,
+		       s  =  4L, t  =  5L,
+		       p  =  6L, v  =  7L,
+		       cp =  8L, cv =  9L,
+		       w  = 10L, rho = 11L,
+		       alpha = 12L, beta = 13L,
+		       kappat = 14L,
+		       eta = 15L, lambda = 16L,
+		       sigma = 17L, epsilon = 18L)
 
 .check_what <- function(what)
 {
