@@ -24,12 +24,13 @@
 #define IAPWS95_R	0.46151805	/* kJ/kg/K */
 #define IAPWS95_PT	611.654771e-06	/* MPa */
 
-int iapws95_phi(double rho, double t, iapws_phi *phi);
+void iapws95_phi(double rho, double t, iapws_phi *phi);
+int iapws95_phi_rhot(double rho, double t, iapws_state_id state, iapws_phi *phi);
 int iapws95_phi_pt(double p, double t, iapws_state_id state, iapws_phi *phi);
 int iapws95_phi_ph(double p, double h, iapws_phi *phi);
-int iapws95_sat(double t, iapws_phi *phil, iapws_phi *phig);
+int iapws95_sat_t(double t, iapws_phi *phil, iapws_phi *phig);
 int iapws95_sat_p(double p, iapws_phi *phil, iapws_phi *phig);
-iapws_state_id iapws95_state(double p, double t);
+iapws_state_id iapws95_state_pt(double p, double t);
 iapws_state_id iapws95_state_rhot(double rho, double t);
 
 #endif
