@@ -19,20 +19,20 @@
 #ifndef IAPWS_NROOT_H
 #define IAPWS_NROOT_H
 
-extern int nroot_verbose;
-extern int nroot_maxiter;
-extern double nroot_tolf;
-extern double nroot_tolx;
+typedef struct {
+	int trace;
+	int maxit;
+	double abstol;
+	double reltol;
+} nroot_control;
+extern nroot_control nroot_default;
 
 typedef void root_fun(double *x, void *prms, double *fx, double *dfx);
-int nroot1(root_fun fun, double *x, void *prms,
-		double *tolf, double *tolx, int *maxiter, int trace);
-int nroot2(root_fun fun, double *x, void *prms,
-		double *tolf, double *tolx, int *maxiter, int trace);
-int nrootn(int n, root_fun fun, double *x, void *prms,
-		double *tolf, double *tolx, int *maxiter, int trace);
 
-int sroot(root_fun fun, double *x, void *prms,
-		double *tolf, double *tolx, int *maxiter, int trace);
+int nroot1(root_fun fun, double *x, void *prms, nroot_control *ctrl);
+int nroot2(root_fun fun, double *x, void *prms, nroot_control *ctrl);
+int nrootn(int n, root_fun fun, double *x, void *prms, nroot_control *ctrl);
+
+int sroot(root_fun fun, double *x, void *prms, nroot_control *ctrl);
 
 #endif
